MaxRectsBin

Struct MaxRectsBin 

pub struct MaxRectsBin { /* private fields */ }
A two-dimensional rectangle bin packer using the MAXRECTS data structure and different bin packing algorithms that use this structure.

It can be used to pack multiple rectangles of arbitrary size into a “bin” of rectangular shape with the goal to add as many rectangles as possible into the bin.

Implementations

Source

impl MaxRectsBin

pub fn new(width: i32, height: i32) -> Self

Creates an empty bin of the given size.

Minimum width and height of a bin is 1.

pub fn with_capacity(width: i32, height: i32, capacity: usize) -> Self

Creates an empty bin of the given size and reserves space for at least capacity number of mapped rectangle to improve performance.

Minimum width and height of a bin is 1.

pub fn default_rule(&self) -> Heuristic

Returns the default Heuristic rule, which is used by the BinPacker trait’s insert and insert_list methods.

pub fn set_default_rule(&mut self, rule: Heuristic)

Can be used to override the default Heuristic rule, which is used by the BinPacker trait’s insert and insert_list methods.

pub fn insert(&mut self, dim: &Dimension, rule: Heuristic) -> Option<Rectangle>

Inserts a single Dimension object into the bin.

dim refers to the object to be packed into the bin.

rule specifies the rectangle placement rule to use for the packing operation.

Returns a copy of the packed Rectangle if the object was inserted successful, or None otherwise.

pub fn insert_list( &mut self, nodes: &[Dimension], rule: Heuristic, ) -> (Vec<Rectangle>, Vec<Dimension>)

Attempts to insert the given list of Dimension objects into the bin.

nodes specifies the list of Dimension objects to insert. All successfully inserted objects will be removed from the list in the process.

rule specifies the rectangle placement rule to use for the packing operations.

Returns a list with all successfully inserted Rectangle objects.

This method performs slower than insert, but may result in more tightly packed bins for greater numbers of dimension objects.