pub struct MaxRectsBin { /* private fields */ }Expand description
A two-dimensional rectangle bin packer using the MAXRECTS data structure and different bin packing algorithms that use this structure.
It can be used to pack multiple rectangles of arbitrary size into a “bin” of rectangular shape with the goal to add as many rectangles as possible into the bin.
Implementations
Sourceimpl MaxRectsBin
impl MaxRectsBin
Sourcepub fn new(width: i32, height: i32) -> Self
pub fn new(width: i32, height: i32) -> Self
Creates an empty bin of the given size.
Minimum width and height of a bin is 1.
Sourcepub fn with_capacity(width: i32, height: i32, capacity: usize) -> Self
pub fn with_capacity(width: i32, height: i32, capacity: usize) -> Self
Creates an empty bin of the given size and reserves space for at least capacity number
of mapped rectangle to improve performance.
Minimum width and height of a bin is 1.
Sourcepub fn default_rule(&self) -> Heuristic
pub fn default_rule(&self) -> Heuristic
Returns the default Heuristic rule, which is used by the BinPacker trait’s
insert and insert_list methods.
Sourcepub fn set_default_rule(&mut self, rule: Heuristic)
pub fn set_default_rule(&mut self, rule: Heuristic)
Can be used to override the default Heuristic rule, which is used by the BinPacker
trait’s insert and insert_list methods.
Sourcepub fn insert_list(
&mut self,
nodes: &[Dimension],
rule: Heuristic,
) -> (Vec<Rectangle>, Vec<Dimension>)
pub fn insert_list( &mut self, nodes: &[Dimension], rule: Heuristic, ) -> (Vec<Rectangle>, Vec<Dimension>)
Attempts to insert the given list of Dimension objects into the bin.
nodes specifies the list of Dimension objects to insert. All successfully inserted
objects will be removed from the list in the process.
rule specifies the rectangle placement rule to use for the packing operations.
Returns a list with all successfully inserted Rectangle objects.
This method performs slower than insert, but may result in more tightly
packed bins for greater numbers of dimension objects.